{% load i18n %}
<fieldset>
	<legend>{% trans "Payment Details" %}</legend>
	<ul id="card-fields">
		{{ form.card_name_field.as_ul }}
		{{ form.card_type_field.as_ul }}
		{{ form.card_type_field.as_ul }}
		<li class="clearfix">
			<label>{% trans "Expiry" %}:</label>
			{{ form.card_expiry_fields.as_p }}
		</li>
		{{ form.card_fields.as_ul }}
	</ul>
</fieldset>

