{% extends "base.html" %}
{% load mezzanine_tags shop_tags i18n %}

{% block title %}{% trans "Your wishlist" %}{% endblock %}

{% block breadcrumb_menu %}
<ul>
    <li><a href="{% url home %}">{% trans "Home" %}</a> &gt;</li>
    <li>{% trans "Your wishlist" %}</li>
</ul><br />
{% endblock %}

{% block main %}
{% if wishlist %}
<table id="items" border="0" cellpadding="5" cellspacing="0">
	{% for item in wishlist %}
	<tr class="{% cycle 'row1' 'row2' %}">
		<td class="items-item">
			{% if item.image %}
			<a href="{{ item.get_absolute_url }}"><img alt="{{ item }}"
				src="{{ MEDIA_URL }}{% thumbnail item.image.file 30 30 %}" /></a>
			{% endif %}
			<a href="{{ item.get_absolute_url }}">{{ item }}</a>
		</td>
		<td class="buttons">
			<form method="post">
                {% csrf_token %}
				<input type="hidden" name="sku" value="{{ item.sku }}" />
				<input type="submit" name="remove_wishlist" value="{% trans "Remove" %}" />
				<input type="submit" name="add_cart" value="{% trans "Buy now" %}" />
			</form>
		</td>
	</tr>
	{% endfor %}
</table>
{% else %}
<p>{% trans "Your wishlist is empty." %}</p>
{% endif %}
{% endblock %}

