/*------ REPLACE THIS WITH YOUR CUSTOM CSS --------- */
* {
    font-family:Garamond, Georgia, serif;
}
.grid {
    padding:30px 0;
}
#grid-top {
    background:#ccc; border-bottom:1px solid #999;
    text-align:center; padding:0;
}
#grid-top li {
    display:inline-block;
    border-right:1px solid #999; padding:10px 20px;
}
#grid-top .first {
    border-left:1px solid #999;
}
#grid-top .active {
    background:#eee;
}
.container_12 {
    background:#e9e9e9;
}
#grid-middle {
    background:#fff; min-height:100%;
}
#grid-middle img {
    max-width:400px;
}
.gutter {
    padding:0 30px;
}
#grid-left {
    font-size:130%;
}
#grid-left li {
    display:block; margin:5px 30px;
}
#grid-left ul ul li {
    list-style-type:disc; font-size:80%;
}
#grid-middle ul {
    list-style:disc;
}
#grid-middle ol {
    list-style:decimal;
}
#grid-middle blockquote {
    border-left: 1px solid #333;
    margin-left: 30px;
}
#grid-middle blockquote p {
    margin-left: 10px;
    line-height: 100%;
}
#grid-right li {
    display:block; margin-top:3px;
}
#grid-bottom {
    background:#666;
}
#grid-bottom .container_12 {
    background:#555;
}
#grid-bottom .grid {
    background:#444; border:1px solid #333;
    border-top:0; border-bottom:0;
}
#grid-bottom ul {
    margin:0 30px;
}
#grid-bottom ul ul {
    margin:0;
}
#grid-bottom li {
    float:left;
}
#grid-bottom li li {
    width:100px; clear:both; margin:5px;
    border:1px solid #333; background:#555; padding:5px 10px;
    border-right:0; border-bottom:0;
}
h2,
p,
#breadcrumb-menu,
#description,
.paging,
.share,
#comments,
.comment {
    margin:20px 0;
}
h1 {
    font-size:250%; border-bottom:1px solid #ccc; font-weight:normal;
}
h2 {
    font-size:150%;
}
h3 {
    font-weight:normal; margin:20px 0 10px;
}
h4 {
    font-weight:bold; margin-top:10px;
}
h5 {
    font-weight:bold; margin-top:20px;
}
a {
    color:#008;
}
table {margin-bottom:30px;}
td, th {padding:3px;}
.active,
.active .active {
    font-style:italic;
}
.active li {
    font-style:normal;
}
p {
    line-height:150%;
}
pre,
pre *,
code,
code * {
    font-family:monospace;
}
pre {
    padding:15px;
}
#breadcrumb-menu li {
    list-style-type:none; display:inline;
    margin-left:0px;
}
input,
textarea {
    border:1px solid #999;
}
textarea {
    width:100%;
}
td, th {
    padding:4px;
}
#grid-bottom a {
    color:#eee; text-decoration:none;
}
.since {
    display:block; margin-bottom:20px;
}
.paging {
    border-top:1px solid #ccc;
}
.paging li {
    padding:0 5px; margin:0 !important;
}
.paging * {
    display:inline;
}
.button {
    cursor:pointer;
}
.help {
    font-size:60%; margin:0;
}
.tags ul,
.tags li {
    display:inline !important; margin:0 !important;
}
.share {
    background:#eee; padding:5px;
}
.button {
    float:right; padding:10px; margin:10px;
}
.form li {
    display:block; padding:5px 10px;
}
#search .button {
    margin:0; padding:1px 5px; float:none;
}
#comments p {
    border-bottom:1px solid #ddd;
}
#comments li {
    padding:5px; display:block;
}
#comments li ul {
    padding:5px 0 0 30px;
}
#comments img {
    margin-right:5px; vertical-align:middle;
}
.comment {
    background:#eee;
}
.comment th,
.comment td {
    text-align:left; vertical-align:top;
    padding:5px 10px;
}
.comment .button {
    margin-right:0px !important;
}
.author {
    background:#fafbd2;
}
ul .comment {
    display:none;
}
ul .posted {
    display:block !important;
}
.comment
.errorlist li {
    color:#f00; float:left; width:100%;
    padding:0 !important;
}
.tag-weight-1 {
    font-size:80%;
}
.tag-weight-2 {
    font-size:120%;
}
.tag-weight-3 {
    font-size:160%;
}
.tag-weight-4 {
    font-size:200%;
}
.tweets li {
    font-size:70%; clear:both; margin-bottom:10px;
    line-height:130%;
}
.tweets img {
    float:left; border:1px solid #000; margin:0 5px 5px 0;
    width:32px; height:32px;
}
.tweets .timespan {
    font-style:italic;
    color: #666;
}
.tweets .name {
    color: #666;
}
.recycle {
    font-size:150%;
}
.retweet  {
    float:none; margin-bottom:-5px; width:16px; height:16px;
}
.mezzanine {
    font-size:80%;
}
.form {
    background:#eee; border-bottom:1px solid #ccc; float:left;
}
.form li ul,
.form li li {
    display:inline;
}
.form li label {
    width:30%; float:left;
}
.form li li label {
    width:auto; float:none;cursor:pointer;
}
#search-results p {
    margin:5px 0;
}
