{% extends "shop/checkout.html" %}
{% load i18n shop_tags %}

{% block fields %}
{% if cart.has_items %}
{% for field, value in form.values %}
<p class="confirmation">{{ field }}: {{ value }}</p>
{% endfor %}
{% for field in form %}{{ field }}{% endfor %}
{% endif %}
{% endblock %}

