{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Order Complete" %}{% endblock %}

{% block breadcrumb_menu %}
<ul>
    <li><a href="{% url home %}">{% trans "Home" %}</a> &gt;</li>
    <li>{% trans "Checkout" %}</li>
</ul><br />
{% endblock %}

{% block main %}
<div>{% trans "Order complete" %}</div>
{% endblock %}

